@@ -1,13 +1,11 @@
 package Test::Perinci::Tx::Manager;
 
-our $DATE = '2017-07-10'; # DATE
-our $VERSION = '0.57'; # VERSION
-
 use 5.010;
 use strict;
 use warnings;
 use Log::ger;
 
+use Exporter qw(import);
 use File::Remove qw(remove);
 use Perinci::Access::Schemeless;
 use Perinci::Tx::Manager;
@@ -15,8 +13,11 @@ use Scalar::Util qw(blessed);
 use Test::More 0.98;
 use UUID::Random;
 
-require Exporter;
-our @ISA = qw(Exporter);
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-11-17'; # DATE
+our $DIST = 'Perinci-Tx-Manager'; # DIST
+our $VERSION = '0.580'; # VERSION
+
 our @EXPORT_OK = qw(test_tx_action);
 
 # note: performing transaction actions is done via riap, just for convenience as
@@ -62,7 +63,7 @@ sub test_tx_action {
 
         my $num_actions = 0;
         my $num_undo_actions = 0;
-        no strict 'refs';
+        no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
         $res = *{$f}{CODE}->(%$fargs, -tx_action=>'check_state');
         my $has_do_actions;
         if ($res->[0] == 200) {
@@ -522,7 +523,7 @@ Test::Perinci::Tx::Manager - Transaction tests
 
 =head1 VERSION
 
-This document describes version 0.57 of Test::Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2017-07-10.
+This document describes version 0.580 of Test::Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2023-11-17.
 
 =head1 FUNCTIONS
 
@@ -580,6 +581,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Tx
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-Tx-Manager>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Tx-Manager>
@@ -588,15 +618,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
